@@ -161,6 +161,16 @@ class PostgreSQL(BaseSQLQueryRunner):
             ],
         }
 
+    def create_options(self, configuration):
+        options = {
+            "user": configuration.get("username"),
+            "password": configuration.get("password"),
+            "host": configuration.get("host"),
+            "port": configuration.get("port"),
+            "dbname": configuration.get("dbname"),
+        }
+        return options
+
     @classmethod
     def type(cls):
         return "pg"
